@@ -1,7 +1,7 @@
-__version__ = "0.5.4"
+__version__ = "0.5.6"
 
 
 from ._internal.parser import DynamoDBStatementParser, S3SelectParser  # noqa
-from ._internal.json_parser import SelectEncoder  # noqa
+from ._internal.json_parser import SelectEncoder, JsonParser  # noqa
 from ._internal.csv_converter import csv_to_json, json_to_csv  # noqa
 from ._internal.utils import MissingVariable, QueryMetadata  # noqa
